@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Capture::Tiny;
 # ABSTRACT: Capture STDOUT and STDERR from Perl, XS or external programs
-our $VERSION = '0.32';
+our $VERSION = '0.44';
 use Carp ();
 use Exporter ();
 use IO::Handle ();
@@ -436,7 +436,7 @@ Capture::Tiny - Capture STDOUT and STDERR from Perl, XS or external programs
 
 =head1 VERSION
 
-version 0.32
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -619,7 +619,7 @@ for test result by platform.
 
 =head2 PerlIO layers
 
-Capture::Tiny does it's best to preserve PerlIO layers such as ':utf8' or
+Capture::Tiny does its best to preserve PerlIO layers such as ':utf8' or
 ':crlf' when capturing (only for Perl 5.8.1+) .  Layers should be applied to
 STDOUT or STDERR I<before> the call to C<capture> or C<tee>.  This may not work
 for tied filehandles (see below).
@@ -705,6 +705,11 @@ capture, it will shortcut in the child process and return empty strings for
 captures.  Other problems may occur in the child or parent, as well.
 Forking in a capture block is not recommended.
 
+=head3 Dropping privileges during a capture
+
+If you drop privileges during a capture, temporary files created to
+facilitate the capture may not be cleaned up afterwards.
+
 =head2 No support for Perl 5.8.0
 
 It's just too buggy when it comes to layers and UTF-8.  Perl 5.8.1 or later
@@ -729,7 +734,7 @@ waiting for its child processes to be ready to proceed.
 
 =head1 SEE ALSO
 
-This module was, inspired by L<IO::CaptureOutput>, which provides
+This module was inspired by L<IO::CaptureOutput>, which provides
 similar functionality without the ability to tee output and with more
 complicated code and API.  L<IO::CaptureOutput> does not handle layers
 or most of the unusual cases described in the L</Limitations> section and
@@ -853,7 +858,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Dagfinn Ilmari Mannsåker David E. Wheeler fecundf
+=for stopwords Dagfinn Ilmari Mannsåker David E. Wheeler fecundf Peter Rabbitson
 
 =over 4
 
@@ -869,6 +874,10 @@ David E. Wheeler <david@justatheory.com>
 
 fecundf <not.com+github@gmail.com>
 
+=item *
+
+Peter Rabbitson <ribasushi@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
